@@ -14,7 +14,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/afs_dcache.c,v 1.42.2.19 2005/10/13 18:42:27 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/afs_dcache.c,v 1.42.2.22 2007/08/20 17:53:15 shadow Exp $");
 
 #include "afs/sysincludes.h"	/*Standard vendor system headers */
 #include "afsincludes.h"	/*AFS-based standard headers */
@@ -1201,14 +1201,14 @@ afs_FindDCache(register struct vcache *avc, afs_size_t abyte)
 	}
 	index = afs_dcnextTbl[index];
     }
-    MReleaseWriteLock(&afs_xdcache);
     if (index != NULLIDX) {
 	hset(afs_indexTimes[tdc->index], afs_indexCounter);
 	hadd32(afs_indexCounter, 1);
+	MReleaseWriteLock(&afs_xdcache);
 	return tdc;
-    } else
-	return NULL;
-
+    } 
+    MReleaseWriteLock(&afs_xdcache);
+    return NULL;
 }				/*afs_FindDCache */
 
 
@@ -2382,17 +2382,19 @@ afs_GetDCache(register struct vcache *avc, afs_size_t abyte,
 	    }
 	    ReleaseWriteLock(&tdc->lock);
 	    afs_PutDCache(tdc);
-	    ObtainWriteLock(&afs_xcbhash, 454);
-	    afs_DequeueCallback(avc);
-	    avc->states &= ~(CStatd | CUnique);
-	    ReleaseWriteLock(&afs_xcbhash);
-	    if (avc->fid.Fid.Vnode & 1 || (vType(avc) == VDIR))
-		osi_dnlc_purgedp(avc);
-	    /*
-	     * Locks held:
-	     * avc->lock(W); assert(!setLocks || slowPass)
-	     */
-	    osi_Assert(!setLocks || slowPass);
+	    if (!afs_IsDynroot(avc)) {
+		ObtainWriteLock(&afs_xcbhash, 454);
+		afs_DequeueCallback(avc);
+		avc->states &= ~(CStatd | CUnique);
+		ReleaseWriteLock(&afs_xcbhash);
+		if (avc->fid.Fid.Vnode & 1 || (vType(avc) == VDIR))
+		    osi_dnlc_purgedp(avc);
+		/*
+		 * Locks held:
+		 * avc->lock(W); assert(!setLocks || slowPass)
+		 */
+		osi_Assert(!setLocks || slowPass);
+	    }
 	    tdc = NULL;
 	    goto done;
 	}
@@ -2736,7 +2738,7 @@ afs_UFSGetDSlot(register afs_int32 aslot, register struct dcache *tmpdc)
     if (CheckLock(&afs_xdcache) != -1)
 	osi_Panic("getdslot nolock");
     if (aslot < 0 || aslot >= afs_cacheFiles)
-	osi_Panic("getdslot slot");
+	osi_Panic("getdslot slot %d (of %d)", aslot, afs_cacheFiles);
     tdc = afs_indexTable[aslot];
     if (tdc) {
 	QRemove(&tdc->lruq);	/* move to queue head */
