@@ -17,7 +17,7 @@
 #endif
 
 RCSID
-    ("$Header: /cvs/openafs/src/auth/ktc.c,v 1.15.2.6 2006/10/06 12:44:40 shadow Exp $");
+    ("$Header: /cvs/openafs/src/auth/ktc.c,v 1.15.2.7 2007/08/09 14:59:54 shadow Exp $");
 
 #if defined(UKERNEL)
 #include "afs/sysincludes.h"
@@ -1163,6 +1163,7 @@ afs_tf_get_cred(principal, token)
 {
     int k_errno;
     int kvno, lifetime;
+    long mit_compat;		/* MIT Kerberos 5 with Krb4 uses a "long" for issue_date */
 
     if (fd < 0) {
 	return TKT_FIL_INI;
@@ -1199,10 +1200,10 @@ afs_tf_get_cred(principal, token)
 	/* don't try to read a silly amount into ticket->dat */
 	token->ticketLen > MAXKTCTICKETLEN
 	|| tf_read((char *)(token->ticket), token->ticketLen) < 1
-	|| tf_read((char *)&(token->startTime),
-		   sizeof(token->startTime)) < 1) {
+	|| tf_read((char *)&mit_compat, sizeof(mit_compat)) < 1) {
 	return TKT_FIL_FMT;
     }
+    token->startTime = mit_compat;
     token->endTime = life_to_time(token->startTime, lifetime);
     token->kvno = kvno;
     return 0;
@@ -1330,6 +1331,7 @@ afs_tf_save_cred(aserver, atoken, aclient)
     off_t start;
     int lifetime, kvno;
     int count;			/* count for write */
+    long mit_compat;		/* MIT Kerberos 5 with Krb4 uses a "long" for issue_date */
 
     if (fd < 0) {		/* fd is ticket file as set by afs_tf_init */
 	return TKT_FIL_INI;
@@ -1399,8 +1401,9 @@ afs_tf_save_cred(aserver, atoken, aclient)
     if (write(fd, atoken->ticket, count) != count)
 	goto bad;
     /* Issue date */
-    if (write(fd, (char *)&atoken->startTime, sizeof(afs_int32))
-	!= sizeof(afs_int32))
+    mit_compat = atoken->startTime;
+    if (write(fd, (char *)&mit_compat, sizeof(mit_compat))
+	!= sizeof(mit_compat))
 	goto bad;
 
     /* Actually, we should check each write for success */
