@@ -27,9 +27,7 @@
 #define AFS_NAMEI_ENV     1	/* User space interface to file system */
 
 #if defined(__KERNEL__) && !defined(KDUMP_KERNEL)
-#include <linux/threads.h>
 
-#include <linux/config.h>
 #ifdef CONFIG_SMP
 #undef CONFIG_SMP
 #endif
@@ -74,6 +72,12 @@
 #endif
 #endif /* KERNEL */
 
+#ifdef __GLIBC__
+#if (__GLIBC__ > 2) || (__GLIBC__ == 2 && __GLIBC_MINOR__ > 3)
+#define USE_UCONTEXT
+#endif
+#endif
+
 #endif /* AFS_PARAM_H */
 
 #else /* !defined(UKERNEL) */
