@@ -11,7 +11,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/kauth/manyklog.c,v 1.7 2003/07/15 23:15:17 shadow Exp $");
+    ("$Header: /cvs/openafs/src/kauth/manyklog.c,v 1.7.2.1 2007/04/10 18:43:43 shadow Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
@@ -214,7 +214,7 @@ CommandProc(as, arock)
     p if (code || !(lcell = ka_LocalCell())) {
       nocell:
 	if (!Silent)
-	    com_err(rn, code, "Can't get local cell name!");
+	    afs_com_err(rn, code, "Can't get local cell name!");
 	KLOGEXIT(code);
     }
     if (code = ka_CellToRealm(lcell, lrealm, 0))
@@ -251,7 +251,7 @@ CommandProc(as, arock)
 	code = ubik_ParseClientList(i, ap, serverList);
 	if (code) {
 	    if (!Silent) {
-		com_err(rn, code, "could not parse server list");
+		afs_com_err(rn, code, "could not parse server list");
 	    }
 	    return code;
 	}
@@ -350,7 +350,7 @@ CommandProc(as, arock)
 	strcpy(realm, lcell);
     if (code = ka_CellToRealm(realm, realm, &local)) {
 	if (!Silent)
-	    com_err(rn, code, "Can't convert cell to realm");
+	    afs_com_err(rn, code, "Can't convert cell to realm");
 	KLOGEXIT(code);
     }
 
