@@ -11,7 +11,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/log/tokens.c,v 1.6 2003/07/15 23:15:41 shadow Exp $");
+    ("$Header: /cvs/openafs/src/log/tokens.c,v 1.6.2.2 2006/03/15 18:29:03 shadow Exp $");
 
 #include <stdio.h>
 #ifdef	AFS_AIX32_ENV
@@ -46,17 +46,15 @@ RCSID
 
 #include "AFS_component_version_number.c"
 
-main(argc, argv)
-     int argc;
-     char **argv;
-
+int
+main(int argc, char **argv)
 {				/*Main program */
     int cellNum;		/*Cell entry number */
     int rc;			/*Return value from U_CellGetLocalTokens */
     time_t current_time;	/*Current time of day */
     time_t tokenExpireTime;	/*When token expires */
     char *expireString;		/*Char string of expiration time */
-    char UserName[16];		/*Printable user name */
+    char UserName[MAXKTCNAMELEN * 2 + 2]; /*Printable user name */
     struct ktc_principal serviceName, clientName;	/* service name for ticket */
     struct ktc_token token;	/* the token we're printing */
 
