@@ -13,7 +13,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/lwp/process.c,v 1.21.2.2 2006/03/31 05:53:01 shadow Exp $");
+    ("$Header: /cvs/openafs/src/lwp/process.c,v 1.21.2.4 2007/07/17 03:13:59 shadow Exp $");
 
 #include <stdio.h>
 #include <assert.h>
@@ -142,6 +142,35 @@ static char (*EP) ();
 static int rc;
 static jmp_buf_type *jmpBuffer;
 
+/** Starting with Glibc 2.4 pointers in jmp_buf are mangled (XOR) for "protection".
+  * On Sparc ucontext functions are not implemented.
+  */
+#define ptr_mangle(x) (x)
+#ifdef AFS_LINUX20_ENV
+
+#ifdef __GLIBC__
+#if (__GLIBC__ > 2) || (__GLIBC__ == 2 && __GLIBC_MINOR__ > 3)
+
+#if defined(AFS_SPARC64_LINUX24_ENV) || defined(AFS_SPARC_LINUX24_ENV)
+/* technically we should use POINTER_GUARD 
+ * ( == offsetof (tcbhead_t, pointer_guard) )
+ * instead of 0x18
+ */
+#undef ptr_mangle
+static int ptr_mangle(int p)
+{   
+    register char *tls_ptr __asm__("%g7");
+    return p ^ *(int*)(tls_ptr + 0x18);
+}
+#else
+#error need ptr_mangle support or use UCONTEXT
+#endif
+
+#endif
+#endif
+#endif
+
+
 afs_int32
 savecontext(ep, savearea, sp)
      char (*ep) ();
@@ -155,7 +184,7 @@ savecontext(ep, savearea, sp)
 
     code = setjmp(savearea->setjmp_buffer);
     jmpBuffer = (jmp_buf_type *) savearea->setjmp_buffer;
-    savearea->topstack = (char *)jmpBuffer[LWP_SP];
+    savearea->topstack = (char *) ptr_mangle(jmpBuffer[LWP_SP]);
 
 #if	defined(DEBUG)
     {
@@ -178,9 +207,9 @@ savecontext(ep, savearea, sp)
 	    switch (rc) {
 	    case 0:
 		jmpBuffer = (jmp_buf_type *) jmp_tmp;
-		jmpBuffer[LWP_SP] = (jmp_buf_type) sp;
+		jmpBuffer[LWP_SP] = ptr_mangle((jmp_buf_type) sp);
 #if defined(AFS_S390_LINUX20_ENV) || defined(AFS_SPARC_LINUX20_ENV) || (defined(AFS_SPARC64_LINUX20_ENV) && defined(AFS_32BIT_USR_ENV))
-		jmpBuffer[LWP_FP] = (jmp_buf_type) sp;
+		jmpBuffer[LWP_FP] = ptr_mangle((jmp_buf_type) sp);
 #endif
 		longjmp(jmp_tmp, 1);
 		break;
