@@ -54,10 +54,11 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/lwp/test/selserver.c,v 1.1.1.5 2003/04/13 19:07:04 hartmans Exp $");
+RCSID
+    ("$Header: /cvs/openafs/src/lwp/test/selserver.c,v 1.7 2003/07/15 23:15:47 shadow Exp $");
 
 
-#include "../lwp.h"
+#include "lwp.h"
 #include "seltest.h"
 
 extern int IOMGR_Select(int, fd_set *, fd_set *, fd_set *, struct timeval *);
@@ -74,7 +75,7 @@ typedef struct {
 #define CH_FREE 0
 #define CH_INUSE 1
     int ch_state;
-    int ch_fd; 
+    int ch_fd;
     struct sockaddr_in ch_addr;
     fd_set ch_read, ch_write, ch_except;
     PROCESS ch_pid;
@@ -84,23 +85,25 @@ void handleWrite(clientHandle_t *, selcmd_t *);
 
 clientHandle_t clientHandles[MAX_THREADS];
 
-clientHandle_t *getClientHandle()
+clientHandle_t *
+getClientHandle()
 {
     int i;
-    for (i=0; i<MAX_THREADS; i++) {
+    for (i = 0; i < MAX_THREADS; i++) {
 	if (clientHandles[i].ch_state == CH_FREE) {
 	    clientHandles[i].ch_state = CH_INUSE;
-	    nThreads ++;
+	    nThreads++;
 	    return &clientHandles[i];
 	}
     }
     Die(1, "No free client handles!\n");
 
-    return (clientHandle_t*)NULL; /* quiet compiler. */
+    return (clientHandle_t *) NULL;	/* quiet compiler. */
 }
 
 int nSigIO = 0;
-void sigIO()
+void
+sigIO()
 {
     nSigIO++;
 }
@@ -119,7 +122,7 @@ main(int ac, char **av)
 {
     int i;
     int on = 1;
-    short port = -1; /* host order. */
+    short port = -1;		/* host order. */
     int setFD = 0;
     struct sockaddr_in saddr;
     int acceptFD;
@@ -140,27 +143,25 @@ main(int ac, char **av)
     signal(SIGIO, sigIO);
 
 
-    for (i=1; i<ac; i++) {
+    for (i = 1; i < ac; i++) {
 	if (!strcmp("-fd", av[i])) {
-	    if (++i>=ac) {
+	    if (++i >= ac) {
 		printf("Missing number for -fd option.\n");
 		Usage();
 	    }
 	    setFD = atoi(av[i]);
-	    if (setFD<=2) {
+	    if (setFD <= 2) {
 		printf("%d: file descriptor must be at least 3.\n", setFD);
 		Usage();
 	    }
-	}
-	else {
+	} else {
 	    if (port == -1) {
 		port = atoi(av[i]);
-		if (port<=0) {
+		if (port <= 0) {
 		    printf("%s: port must be at least 1\n", av[i]);
 		    Usage();
 		}
-	    }
-	    else {
+	    } else {
 		printf("%s: Unknown argument.\n", av[i]);
 	    }
 	}
@@ -181,12 +182,10 @@ main(int ac, char **av)
     IOMGR_Initialize();
 
     /* Setup server processes */
-    for (i=0; i<MAX_THREADS; i++) {
-	if (LWP_CreateProcess(handleRequest, 32768,
-			      LWP_NORMAL_PRIORITY,
-			      (char*)&clientHandles[i],
-			      "HandleRequestThread",
-			      &pid) < 0 ) {
+    for (i = 0; i < MAX_THREADS; i++) {
+	if (LWP_CreateProcess
+	    (handleRequest, 32768, LWP_NORMAL_PRIORITY,
+	     (char *)&clientHandles[i], "HandleRequestThread", &pid) < 0) {
 	    printf("%s: Failed to start all LWP's\n", program);
 	    exit(1);
 	}
@@ -195,25 +194,25 @@ main(int ac, char **av)
 
 
     sockFD = socket(AF_INET, SOCK_STREAM, 0);
-    if (sockFD<0) {
+    if (sockFD < 0) {
 	perror("socket");
 	exit(1);
     }
     Log("Using socket at file descriptor %d.\n", sockFD);
 
-    if (setsockopt(sockFD, SOL_SOCKET, SO_REUSEADDR, (char *) &on,
-		   sizeof(on)) < 0) {
+    if (setsockopt(sockFD, SOL_SOCKET, SO_REUSEADDR, (char *)&on, sizeof(on))
+	< 0) {
 	perror("setsockopt: ");
 	exit(1);
     }
 
-    memset((void*)&saddr, 0, sizeof(saddr));
+    memset((void *)&saddr, 0, sizeof(saddr));
 
     saddr.sin_family = AF_INET;
     saddr.sin_port = ntohs(port);
     saddr.sin_addr.s_addr = htonl(INADDR_ANY);
 
-    if (bind(sockFD, (struct sockaddr*)&saddr, sizeof(saddr))<0) {
+    if (bind(sockFD, (struct sockaddr *)&saddr, sizeof(saddr)) < 0) {
 	perror("bind: ");
 	exit(1);
     }
@@ -227,17 +226,21 @@ main(int ac, char **av)
 	exit(1);
     }
 
-    listen(sockFD, 100) ;
-	
-    
-    while ( 1 ) {
-	FD_ZERO(rfds); FD_ZERO(wfds); FD_ZERO(efds);
-	FD_SET(sockFD, rfds); FD_SET(sockFD, efds);
+    listen(sockFD, 100);
+
+
+    while (1) {
+	FD_ZERO(rfds);
+	FD_ZERO(wfds);
+	FD_ZERO(efds);
+	FD_SET(sockFD, rfds);
+	FD_SET(sockFD, efds);
 
 	Log("Main - going to select.\n");
-	code = IOMGR_Select(sockFD+1, rfds, wfds, efds, (struct timeval*)0);
-	switch(code) {
-	case 0: /* Timer, can't happen here. */
+	code =
+	    IOMGR_Select(sockFD + 1, rfds, wfds, efds, (struct timeval *)0);
+	switch (code) {
+	case 0:		/* Timer, can't happen here. */
 	case -1:
 	case -2:
 	    Log("Oops! select returns %d!\n", code);
@@ -257,9 +260,9 @@ main(int ac, char **av)
 		clientHandle = getClientHandle();
 
 		addr_len = sizeof(clientHandle->ch_addr);
-		clientHandle->ch_fd = accept(sockFD,
-				     (struct sockaddr*)&clientHandle->ch_addr,
-					  &addr_len);
+		clientHandle->ch_fd = accept(sockFD, (struct sockaddr *)
+					     &clientHandle->ch_addr,
+					     &addr_len);
 		if (clientHandle->ch_fd < 0) {
 		    perror("accept: ");
 		    exit(1);
@@ -277,52 +280,53 @@ main(int ac, char **av)
     }
 }
 
-void handleRequest(char *arg)
+void
+handleRequest(char *arg)
 {
-    clientHandle_t *ch = (clientHandle_t*)arg;
+    clientHandle_t *ch = (clientHandle_t *) arg;
     selcmd_t sc;
     struct stat sbuf;
     int code = 0;
     int c_errno = 0;
 
-    while ( 1 ) {
-	Log("(handleRequest) going to sleep on 0x%x\n",
-	       &ch->ch_state);
+    while (1) {
+	Log("(handleRequest) going to sleep on 0x%x\n", &ch->ch_state);
 	LWP_WaitProcess(&ch->ch_state);
 	assert(ch->ch_state == CH_INUSE);
-	
+
 	FD_ZERO(&(ch->ch_read));
 	FD_ZERO(&(ch->ch_write));
 	FD_ZERO(&(ch->ch_except));
-	FD_SET(ch->ch_fd, &(ch->ch_read)); 
-	FD_SET(ch->ch_fd, &(ch->ch_except)); 
-	code = IOMGR_Select(ch->ch_fd + 1, &(ch->ch_read), &(ch->ch_write),
-			     &(ch->ch_except), (struct timeval *)NULL);
+	FD_SET(ch->ch_fd, &(ch->ch_read));
+	FD_SET(ch->ch_fd, &(ch->ch_except));
+	code =
+	    IOMGR_Select(ch->ch_fd + 1, &(ch->ch_read), &(ch->ch_write),
+			 &(ch->ch_except), (struct timeval *)NULL);
 	if (FD_ISSET(ch->ch_fd, &(ch->ch_except))) {
 	    Log("Received expception. Read fd_set shows %d\n",
 		FD_ISSET(ch->ch_fd, &(ch->ch_read)));
-	    assertNullFDSet(ch->ch_fd,  &(ch->ch_read));
-	    assertNullFDSet(-1,  &(ch->ch_write));
-	    assertNullFDSet(ch->ch_fd,  &(ch->ch_except));
+	    assertNullFDSet(ch->ch_fd, &(ch->ch_read));
+	    assertNullFDSet(-1, &(ch->ch_write));
+	    assertNullFDSet(ch->ch_fd, &(ch->ch_except));
 	    goto done;
 	}
-	assert(code>0);
+	assert(code > 0);
 
-	if (read(ch->ch_fd, (char*)&sc, sizeof(sc))!=sizeof(sc)) {
+	if (read(ch->ch_fd, (char *)&sc, sizeof(sc)) != sizeof(sc)) {
 	    Die(1, "(handleRequest) read command");
 	}
-	
+
 	Log("(handleRequest)cmd=%d\n", sc.sc_cmd);
 	fflush(stdout);
 
-	switch(sc.sc_cmd) {
+	switch (sc.sc_cmd) {
 	case SC_PROBE:
 	    Log("Probed from client at %s\n",
-		   inet_ntoa(ch->ch_addr.sin_addr));
+		inet_ntoa(ch->ch_addr.sin_addr));
 	    break;
 #ifdef notdef
 	case SC_OOB:
-	    nThreads --;
+	    nThreads--;
 	    ch->ch_fd = 0;
 	    ch->ch_state = CH_FREE;
 	    return;
@@ -337,10 +341,10 @@ void handleRequest(char *arg)
 	    Log("%d: bad command to handleRequest.\n", sc.sc_cmd);
 	    break;
 	}
-	
-    done:
+
+      done:
 	/* We're done now, so we can be re-used. */
-	nThreads --;
+	nThreads--;
 	close(ch->ch_fd);
 	ch->ch_fd = 0;
 	ch->ch_state = CH_FREE;
@@ -348,7 +352,8 @@ void handleRequest(char *arg)
 }
 
 int write_I = 0;
-void handleWrite(clientHandle_t *ch, selcmd_t *sc)
+void
+handleWrite(clientHandle_t * ch, selcmd_t * sc)
 {
     int i;
     fd_set *rfds, *wfds, *efds;
@@ -363,36 +368,39 @@ void handleWrite(clientHandle_t *ch, selcmd_t *sc)
     efds = IOMGR_AllocFDSet();
     assert(rfds && wfds && efds);
 
-    if (sc->sc_delay>0) {
+    if (sc->sc_delay > 0) {
 	IOMGR_Sleep(sc->sc_delay);
     }
 
-    Log("(handleWrite 0x%x) waking after %d second sleep.\n",
-	   ch->ch_pid, sc->sc_delay);
+    Log("(handleWrite 0x%x) waking after %d second sleep.\n", ch->ch_pid,
+	sc->sc_delay);
 
     if (sc->sc_flags & SC_WAIT_OOB)
 	sendOOB(ch->ch_fd);
 
-    buf = (char*)malloc(sc->sc_info);
+    buf = (char *)malloc(sc->sc_info);
     assert(buf);
     i = 0;
 
-    while ( 1 ) {
-	FD_ZERO(rfds); FD_SET(ch->ch_fd, rfds);
-	FD_ZERO(efds); FD_SET(ch->ch_fd, efds);
+    while (1) {
+	FD_ZERO(rfds);
+	FD_SET(ch->ch_fd, rfds);
+	FD_ZERO(efds);
+	FD_SET(ch->ch_fd, efds);
 	FD_ZERO(wfds);
-	scode = IOMGR_Select(ch->ch_fd+1, rfds, wfds, efds,
-			   (struct timeval*)0);
-	assert(scode>0);
+	scode =
+	    IOMGR_Select(ch->ch_fd + 1, rfds, wfds, efds,
+			 (struct timeval *)0);
+	assert(scode > 0);
 
 	if (FD_ISSET(ch->ch_fd, rfds)) {
 
-	    assert(i<sc->sc_info);
+	    assert(i < sc->sc_info);
 
 	    code = read(ch->ch_fd, &buf[i], 1);
-	    i ++;
-	    write_I ++;
-	    if (code !=1) {
+	    i++;
+	    write_I++;
+	    if (code != 1) {
 		Log("code =%d\n", code);
 		assert(code == 1);
 	    }
@@ -404,7 +412,7 @@ void handleWrite(clientHandle_t *ch, selcmd_t *sc)
 	    if (c == END_DATA || i >= sc->sc_info) {
 		break;
 	    }
-       }
+	}
     }
     Log("Read %d bytes of data.\n", sc->sc_info);
     nbytes = write(ch->ch_fd, buf, sc->sc_info);
