@@ -15,7 +15,7 @@
 #endif
 
 RCSID
-    ("$Header: /cvs/openafs/src/ptserver/ptuser.c,v 1.16.2.12 2006/10/13 12:46:02 shadow Exp $");
+    ("$Header: /cvs/openafs/src/ptserver/ptuser.c,v 1.16.2.15 2007/04/10 18:43:45 shadow Exp $");
 
 #if defined(UKERNEL)
 #include "afs/sysincludes.h"
@@ -54,6 +54,7 @@ RCSID
 #include <afs/auth.h>
 #include <afs/cellconfig.h>
 #include <afs/afsutil.h>
+#include <afs/com_err.h>
 #include "ptclient.h"
 #include "ptuser.h"
 #include "pterror.h"
@@ -187,7 +188,7 @@ pr_Initialize(IN afs_int32 secLevel, IN char *confDir, IN char *cell)
 	if (code)
 	    fprintf(stderr,
 		    "libprot: clientauthsecure returns %d %s"
-		    " (so trying noauth)\n", code, error_message(code));
+		    " (so trying noauth)\n", code, afs_error_message(code));
 	if (code)
 	    scIndex = 0;	/* use noauth */
 	if (scIndex != 2)
@@ -223,7 +224,7 @@ pr_Initialize(IN afs_int32 secLevel, IN char *confDir, IN char *cell)
     if ((scIndex == 0) && (sc[0] == 0))
 	sc[0] = rxnull_NewClientSecurityObject();
     if ((scIndex == 0) && (secLevel != 0))
-	com_err(whoami, code,
+	afs_com_err(whoami, code,
 		"Could not get afs tokens, running unauthenticated.");
 
     memset(serverconns, 0, sizeof(serverconns));	/* terminate list!!! */
@@ -235,7 +236,7 @@ pr_Initialize(IN afs_int32 secLevel, IN char *confDir, IN char *cell)
 
     code = ubik_ClientInit(serverconns, &pruclient);
     if (code) {
-	com_err(whoami, code, "ubik client init failed.");
+	afs_com_err(whoami, code, "ubik client init failed.");
 	return code;
     }
     lastLevel = scIndex;
@@ -681,7 +682,10 @@ pr_ChangeEntry(char *oldname, char *newname, afs_int32 *newid, char *newowner)
 	if (oid == ANONYMOUSID)
 	    return PRNOENT;
     }
-    code = ubik_PR_ChangeEntry(pruclient, 0, id, newname, oid, *newid);
+    if (newid)
+	code = ubik_PR_ChangeEntry(pruclient, 0, id, newname, oid, *newid);
+    else
+	code = ubik_PR_ChangeEntry(pruclient, 0, id, newname, oid, 0);
     return code;
 }
 
