@@ -38,7 +38,7 @@
 #endif
 
 RCSID
-    ("$Header: /cvs/openafs/src/rxkad/bg-fcrypt.c,v 1.5.2.3 2006/08/02 19:07:04 shadow Exp $");
+    ("$Header: /cvs/openafs/src/rxkad/bg-fcrypt.c,v 1.5.2.5 2007/07/31 22:22:21 shadow Exp $");
 
 #define DEBUG 0
 #ifdef KERNEL
@@ -550,8 +550,8 @@ fc_keysched(void *key_, fc_KeySchedule sched)
     const unsigned char *key = key_;
 
     /* Do we have 56 bit longs or even longer longs? */
-#if ((1ul << 31) << 1) && defined(ULONG_MAX) && ((ULONG_MAX >> 55) != 0) && ((1ul << 55) != 0)
-    unsigned long k;		/* k holds all 56 non parity bits */
+#ifdef AFS_64BIT_ENV
+    afs_uint64 k;		/* k holds all 56 non parity bits */
 
     /* Compress out parity bits */
     k = (*key++) >> 1;
