@@ -11,7 +11,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/update/server.c,v 1.13.2.2 2006/06/20 20:35:01 jaltman Exp $");
+    ("$Header: /cvs/openafs/src/update/server.c,v 1.13.2.3 2007/04/10 18:43:46 shadow Exp $");
 
 #include <afs/stds.h>
 #ifdef	AFS_AIX32_ENV
@@ -50,6 +50,7 @@ RCSID
 #include <afs/cellconfig.h>
 #include <afs/afsutil.h>
 #include <afs/fileutil.h>
+#include <afs/com_err.h>
 #ifdef	AFS_AIX_ENV
 #include <sys/statfs.h>
 #endif
@@ -352,7 +353,7 @@ UPDATE_FetchFile(struct rx_call *call, char *name)
 
     /* construct a local path from a canonical (wire-format) path */
     if ((error = ConstructLocalPath(name, "/", &reqObject))) {
-	com_err(whoami, error, "Unable to construct local path");
+	afs_com_err(whoami, error, "Unable to construct local path");
 	return UPDATE_ERROR;
     }
 
@@ -384,7 +385,7 @@ UPDATE_FetchInfo(struct rx_call *call, char *name)
 
     /* construct a local path from a canonical (wire-format) path */
     if ((error = ConstructLocalPath(name, "/", &reqObject))) {
-	com_err(whoami, error, "Unable to construct local path");
+	afs_com_err(whoami, error, "Unable to construct local path");
 	return UPDATE_ERROR;
     }
 
@@ -559,14 +560,14 @@ AddObject(char **expPath, char *dir)
 
     /* construct a local path from a canonical (wire-format) path */
     if ((error = ConstructLocalPath(dir, "/", expPath))) {
-	com_err(whoami, error, "Unable to construct local path");
+	afs_com_err(whoami, error, "Unable to construct local path");
 	return error;
     }
 
     /* stat the object */
     error = stat(*expPath, &statbuf);
     if (error) {
-	com_err(whoami, error, ";Can't stat object.");
+	afs_com_err(whoami, error, ";Can't stat object.");
 	return error;
     }
     /* now check if the object has an exportable (file/dir)  type */
