@@ -20,7 +20,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/util/serverLog.c,v 1.22.2.1 2004/10/18 07:12:18 shadow Exp $");
+    ("$Header: /cvs/openafs/src/util/serverLog.c,v 1.22.2.11 2006/06/07 04:27:20 shadow Exp $");
 
 #include <stdio.h>
 #ifdef AFS_NT40_ENV
@@ -44,6 +44,7 @@ RCSID
 #include <strings.h>
 #endif
 #endif
+#include <sys/stat.h>
 #include "afsutil.h"
 #include "fileutil.h"
 #if defined(AFS_PTHREAD_ENV)
@@ -66,9 +67,15 @@ static pthread_mutex_t serverLogMutex;
 
 #ifdef AFS_NT40_ENV
 #define F_OK 0
+#define O_NONBLOCK 0
 #endif
 
-char *(*threadNameProgram) ();
+static int
+dummyThreadNum(void)
+{
+    return -1;
+}
+static int (*threadNumProgram) () = dummyThreadNum;
 
 static int serverLogFD = -1;
 
@@ -81,9 +88,16 @@ char *serverLogSyslogTag = 0;
 #include <stdarg.h>
 int LogLevel;
 int mrafsStyleLogs = 0;
+static int threadIdLogs = 0;
 int printLocks = 0;
 static char ourName[MAXPATHLEN];
 
+void
+SetLogThreadNumProgram(int (*func) () )
+{
+    threadNumProgram = func;
+}
+
 void
 WriteLogBuffer(char *buf, afs_uint32 len)
 {
@@ -93,6 +107,12 @@ WriteLogBuffer(char *buf, afs_uint32 len)
     UNLOCK_SERVERLOG();
 }
 
+int
+LogThreadNum(void) 
+{
+  return (*threadNumProgram) ();
+}
+
 void
 vFSLog(const char *format, va_list args)
 {
@@ -100,7 +120,7 @@ vFSLog(const char *format, va_list args)
     char *timeStamp;
     char tbuffer[1024];
     char *info;
-    int len;
+    int len, num;
     char *name;
 
     currenttime = time(0);
@@ -108,12 +128,14 @@ vFSLog(const char *format, va_list args)
     timeStamp[24] = ' ';	/* ts[24] is the newline, 25 is the null */
     info = &timeStamp[25];
 
-    if (mrafsStyleLogs) {
-	name = (*threadNameProgram) ();
-	(void)afs_snprintf(info, (sizeof tbuffer) - strlen(tbuffer), "[%s] ",
-			   name);
+    if (mrafsStyleLogs || threadIdLogs) {
+	num = (*threadNumProgram) ();
+        if (num > -1) {
+	(void)afs_snprintf(info, (sizeof tbuffer) - strlen(tbuffer), "[%d] ",
+			   num);
 	info += strlen(info);
     }
+    }
 
     (void)afs_vsnprintf(info, (sizeof tbuffer) - strlen(tbuffer), format,
 			args);
@@ -169,8 +191,20 @@ SetDebug_Signal(int signo)
 
     if (LogLevel > 0) {
 	LogLevel *= 5;
+
+#if defined(AFS_PTHREAD_ENV)
+        if (LogLevel > 1 && threadNumProgram != NULL && 
+            threadIdLogs == 0) {
+            threadIdLogs = 1;
+        }
+#endif
     } else {
 	LogLevel = 1;
+
+#if defined(AFS_PTHREAD_ENV)
+        if (threadIdLogs == 1)
+            threadIdLogs = 0;
+#endif
     }
     printLocks = 2;
 #if defined(AFS_PTHREAD_ENV)
@@ -194,13 +228,17 @@ ResetDebug_Signal(int signo)
 #if defined(AFS_PTHREAD_ENV)
     DebugOn(LogLevel);
 #else /* AFS_PTHREAD_ENV */
-    IOMGR_SoftSig(DebugOn, (void *)LogLevel);
+    IOMGR_SoftSig(DebugOn, LogLevel);
 #endif /* AFS_PTHREAD_ENV */
 
     (void)signal(signo, ResetDebug_Signal);	/* on some platforms,
 						 * this signal handler
 						 * needs to be set
 						 * again */
+#if defined(AFS_PTHREAD_ENV)
+    if (threadIdLogs == 1)
+        threadIdLogs = 0;
+#endif
     if (mrafsStyleLogs)
 	OpenLog((char *)&ourName);
 }				/*ResetDebug_Signal */
@@ -212,6 +250,9 @@ SetupLogSignals(void)
     (void)signal(SIGHUP, ResetDebug_Signal);
     /* Note that we cannot use SIGUSR1 -- Linux stole it for pthreads! */
     (void)signal(SIGTSTP, SetDebug_Signal);
+#ifndef AFS_NT40_ENV
+    (void)signal(SIGPIPE, SIG_IGN);
+#endif
 }
 
 int
@@ -221,22 +262,30 @@ OpenLog(const char *fileName)
      * This function should allow various libraries that inconsistently
      * use stdout/stderr to all go to the same place
      */
-    int tempfd;
+    int tempfd, isfifo = 0;
     char oldName[MAXPATHLEN];
     struct timeval Start;
     struct tm *TimeFields;
     char FileName[MAXPATHLEN];
 
 #ifndef AFS_NT40_ENV
+    struct stat statbuf;
+
     if (serverLogSyslog) {
 	openlog(serverLogSyslogTag, LOG_PID, serverLogSyslogFacility);
 	return (0);
     }
+
+    /* Support named pipes as logs by not rotating them */
+    if ((lstat(fileName, &statbuf) == 0)  && (S_ISFIFO(statbuf.st_mode))) {
+	isfifo = 1;
+    }
 #endif
 
     if (mrafsStyleLogs) {
-        time_t t = Start.tv_sec;
+        time_t t;
 	TM_GetTimeOfDay(&Start, 0);
+        t = Start.tv_sec;	
 	TimeFields = localtime(&t);
 	if (fileName) {
 	    if (strncmp(fileName, (char *)&ourName, strlen(fileName)))
@@ -247,35 +296,41 @@ OpenLog(const char *fileName)
 		     TimeFields->tm_mon + 1, TimeFields->tm_mday,
 		     TimeFields->tm_hour, TimeFields->tm_min,
 		     TimeFields->tm_sec);
-	rename(fileName, FileName);	/* don't check error code */
-	tempfd = open(fileName, O_WRONLY | O_TRUNC | O_CREAT, 0666);
+	if (!isfifo)
+	    renamefile(fileName, FileName);	/* don't check error code */
+	tempfd = open(fileName, O_WRONLY | O_TRUNC | O_CREAT | (isfifo?O_NONBLOCK:0), 0666);
     } else {
 	strcpy(oldName, fileName);
 	strcat(oldName, ".old");
 
 	/* don't check error */
-	renamefile(fileName, oldName);
-	tempfd = open(fileName, O_WRONLY | O_TRUNC | O_CREAT, 0666);
+	if (!isfifo)
+	    renamefile(fileName, oldName);
+	tempfd = open(fileName, O_WRONLY | O_TRUNC | O_CREAT | (isfifo?O_NONBLOCK:0), 0666);
     }
 
     if (tempfd < 0) {
 	printf("Unable to open log file %s\n", fileName);
 	return -1;
     }
-#if defined(AFS_PTHREAD_ENV)
     /* redirect stdout and stderr so random printf's don't write to data */
-    assert(freopen(NULLDEV, "w", stdout) != NULL);
-    assert(freopen(NULLDEV, "w", stderr) != NULL);
+    (void)freopen(fileName, "a", stdout);
+    (void)freopen(fileName, "a", stderr);
+#ifdef HAVE_SETVBUF
+#ifdef SETVBUF_REVERSED
+    setvbuf(stderr, _IONBF, NULL, 0);
+#else
+    setvbuf(stderr, NULL, _IONBF, 0);
+#endif
+#else
+    setbuf(stderr, NULL);
+#endif
 
+#if defined(AFS_PTHREAD_ENV)
     assert(pthread_mutex_init(&serverLogMutex, NULL) == 0);
+#endif /* AFS_PTHREAD_ENV */
 
     serverLogFD = tempfd;
-#else
-    close(tempfd);		/* just checking.... */
-    (void)freopen(fileName, "w", stdout);
-    (void)freopen(fileName, "w", stderr);
-    serverLogFD = fileno(stdout);
-#endif /* AFS_PTHREAD_ENV */
 
     return 0;
 }				/*OpenLog */
@@ -283,9 +338,13 @@ OpenLog(const char *fileName)
 int
 ReOpenLog(const char *fileName)
 {
+    int isfifo = 0;
 #if !defined(AFS_PTHREAD_ENV)
     int tempfd;
 #endif
+#if !defined(AFS_NT40_ENV)
+    struct stat statbuf;
+#endif
 
     if (access(fileName, F_OK) == 0)
 	return 0;		/* exists, no need to reopen. */
@@ -294,29 +353,31 @@ ReOpenLog(const char *fileName)
     if (serverLogSyslog) {
 	return 0;
     }
+
+    /* Support named pipes as logs by not rotating them */
+    if ((lstat(fileName, &statbuf) == 0)  && (S_ISFIFO(statbuf.st_mode))) {
+	isfifo = 1;
+    }
 #endif
 
-#if defined(AFS_PTHREAD_ENV)
     LOCK_SERVERLOG();
     if (serverLogFD > 0)
 	close(serverLogFD);
-    serverLogFD = open(fileName, O_WRONLY | O_APPEND | O_CREAT, 0666);
+    serverLogFD = open(fileName, O_WRONLY | O_APPEND | O_CREAT | (isfifo?O_NONBLOCK:0), 0666);
+    if (serverLogFD > 0) {
+	(void)freopen(fileName, "a", stdout);
+	(void)freopen(fileName, "a", stderr);
+#ifdef HAVE_SETVBUF
+#ifdef SETVBUF_REVERSED
+	setvbuf(stderr, _IONBF, NULL, 0);
+#else
+	setvbuf(stderr, NULL, _IONBF, 0);
+#endif
+#else
+	setbuf(stderr, NULL);
+#endif
+
+    }
     UNLOCK_SERVERLOG();
     return serverLogFD < 0 ? -1 : 0;
-#else
-
-    tempfd = open(fileName, O_WRONLY | O_APPEND | O_CREAT, 0666);
-    if (tempfd < 0) {
-	printf("Unable to open log file %s\n", fileName);
-	return -1;
-    }
-    close(tempfd);
-
-    (void)freopen(fileName, "a", stdout);
-    (void)freopen(fileName, "a", stderr);
-    serverLogFD = fileno(stdout);
-
-
-    return 0;
-#endif /* AFS_PTHREAD_ENV */
 }
